@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -110,7 +110,6 @@ sub BUILD {
         next unless defined $item[1];
         push @{ $halstead{ $item[0] } }, $item[1];
     }
-#use Data::Dumper;warn(__PACKAGE__,' ',__LINE__," MARK: ",Dumper\%halstead);
 
     $self->{n_operators} = 0;
     $self->{n_operands}  = 0;
@@ -136,7 +135,6 @@ sub BUILD {
             }
         }
     }
-#use Data::Dumper;warn(__PACKAGE__,' ',__LINE__," MARK: ",Dumper\%distinct);
 
     $self->{n_distinct_operators} = keys %{ $distinct{operators} };
     $self->{n_distinct_operands}  = keys %{ $distinct{operands} };
@@ -162,6 +160,7 @@ sub _is_operand {
     return $key eq 'PPI::Token::Comment'
         || $key eq 'PPI::Token::Number'
         || $key eq 'PPI::Token::Symbol'
+        || $key eq 'PPI::Token::Pod'
         || $key =~ /Quote/;
 }
 
@@ -184,7 +183,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
